# arirang ruby script example

class Arirang

@ari_port = 3128

     def baedal
        ari_title   = "http proxy connect check\n"
        ari_desc    = "arirang ruby script examples\n"
        ari_author  = "pilot <pilot@monkey.org>\n"

        puts "title: #{ari_title}"
        puts "desc: #{ari_desc}"
        puts "author: #{ari_author}"
     end

     def asadal
         ariconnect
         buf = "CONNECT www.google.com:80 HTTP/1.0\r\n\r\n"
         response = arisend(buf)
         z = "#{$ari_host} - " + response
		 ariprint(z)
     end


end


