# arirang script example

class Arirang

#@ari_port = 80

     def baedal
        ari_title   = "multiple uri check\n"
        ari_desc    = "arirang script examples\n"
        ari_author  = "pilot <pilot@monkey.org>\n"

        puts "title: #{ari_title}"
        puts "desc: #{ari_desc}"
        puts "author: #{ari_author}"

     end

     def asadal
         url = ["GET / HTTP/1.0\r\n\r\n", "HEAD / HTTP/1.0\r\n\r\n" , "GET /robots.txt HTTP/1.0\r\n\r\n"]
         for i in url
         ariconnect
         recv = arisend(i)
         buf = recv.split("\r\n")[0]
         z = "#{$ari_host} - #{buf} - #{i}\n"
         ariprint(z)
         end
     end


end

